==> gameap-3.1-shared.zip: upload/resources/lang/ru/users.php <==
<?php

return [
    'title_list' => 'Список пользователей',
    'title_create' => 'Создание пользователя',
    'title_edit' => 'Редактирование пользователя',

    'title_server_permissions_edit' => 'Редактирование привилегий на сервер',
    
    'users' => 'Пользователи',
    'user' => 'Пользователь',
    'login' => 'Логин',
    'name' => 'Имя',
    'roles' => 'Роли',
    
    'create' => 'Создать пользователя',

    'servers' => 'Серверы',
    'servers_privileges_placeholder' => 'Начните вводить имя сервера',

    'permission_names' => [
        'game-server-common'        => 'Базовые привилегии',
        'game-server-start'         => 'Запуск игрового сервера',
        'game-server-stop'          => 'Остановка игрового сервера',
        'game-server-restart'       => 'Перезагрузка игрового сервера',
        'game-server-pause'         => 'Пауза игрового сервера',
        'game-server-update'        => 'Обновление игрового сервера',
        'game-server-console-view'  => 'Чтение консоли',
        'game-server-tasks'         => 'Доступ к заданиям сервера',
        'game-server-settings'      => 'Доступ к настройкам',

        // Console
        'game-server-console-send'  => 'Отправка комманд в консоль',
        'game-server-files'         => 'Доступ к файловому менеджеру',

        // RCON
        'game-server-rcon-console'  => 'RCON консоль',
        'game-server-rcon-players'  => 'RCON управление игроками',
    ],

    'server_permission_edit' => 'Привилегии сервера',

    'create_success_msg' => 'Пользователь успешно создан',
    'update_success_msg' => 'Пользователь успешно обновлён',
    'delete_success_msg' => 'Пользователь успешно улалён',
];

==> gameap-3.2-shared.zip: upload/resources/lang/ru/users.php <==
<?php

return [
    'title_list' => 'Список пользователей',
    'title_create' => 'Создание пользователя',
    'title_edit' => 'Редактирование пользователя',

    'title_server_permissions_edit' => 'Редактирование привилегий на сервер',
    
    'users' => 'Пользователи',
    'user' => 'Пользователь',
    'login' => 'Логин',
    'name' => 'Имя',
    'roles' => 'Роли',
    
    'create' => 'Создать пользователя',

    'servers' => 'Серверы',
    'servers_privileges_placeholder' => 'Начните вводить имя сервера',

    'permission_names' => [
        'game-server-common'        => 'Базовые привилегии',
        'game-server-start'         => 'Запуск игрового сервера',
        'game-server-stop'          => 'Остановка игрового сервера',
        'game-server-restart'       => 'Перезагрузка игрового сервера',
        'game-server-pause'         => 'Пауза игрового сервера',
        'game-server-update'        => 'Обновление игрового сервера',
        'game-server-console-view'  => 'Чтение консоли',
        'game-server-tasks'         => 'Доступ к заданиям сервера',
        'game-server-settings'      => 'Доступ к настройкам',

        // Console
        'game-server-console-send'  => 'Отправка комманд в консоль',
        'game-server-files'         => 'Доступ к файловому менеджеру',

        // RCON
        'game-server-rcon-console'  => 'RCON консоль',
        'game-server-rcon-players'  => 'RCON управление игроками',
    ],

    'update_password' => 'Обновление пароля',

    'server_permission_edit' => 'Привилегии сервера',

    'delete_confirm_msg' => 'Вы уверены, что хотите удалить этого пользователя?',

    'create_success_msg' => 'Пользователь успешно создан',
    'update_success_msg' => 'Пользователь успешно обновлён',
    'delete_success_msg' => 'Пользователь успешно удалён',

    'privileges_saved_success_msg' => 'Привилегии успешно сохранены',

    'delete_self_error_msg' => 'Вы не можете удалить себя',
];
